@@ -6,6 +6,7 @@ from langtrace_python_sdk.utils.llm import (
     get_llm_request_attributes,
     get_llm_url,
     set_event_completion,
+    set_event_completion_chunk,
 )
 from langtrace_python_sdk.utils.silently_fail import silently_fail
 from langtrace_python_sdk.constants.instrumentation.common import SERVICE_PROVIDERS
@@ -166,24 +167,21 @@ def _handle_streaming_response(span, response, api):
     accumulated_tokens = None
     if api == "chat":
         accumulated_tokens = {"message": {"content": "", "role": ""}}
-    if api == "completion":
+    if api == "completion" or api == "generate":
         accumulated_tokens = {"response": ""}
     span.add_event(Event.STREAM_START.value)
     try:
         for chunk in response:
+            content = None
             if api == "chat":
+                content = chunk["message"]["content"]
                 accumulated_tokens["message"]["content"] += chunk["message"]["content"]
                 accumulated_tokens["message"]["role"] = chunk["message"]["role"]
             if api == "generate":
+                content = chunk["response"]
                 accumulated_tokens["response"] += chunk["response"]
 
-            span.add_event(
-                Event.STREAM_OUTPUT.value,
-                {
-                    SpanAttributes.LLM_CONTENT_COMPLETION_CHUNK: chunk.get("response")
-                    or chunk.get("message").get("content"),
-                },
-            )
+            set_event_completion_chunk(span, content)
 
         _set_response_attributes(span, chunk | accumulated_tokens)
     finally:
@@ -199,24 +197,22 @@ async def _ahandle_streaming_response(span, response, api):
     accumulated_tokens = None
     if api == "chat":
         accumulated_tokens = {"message": {"content": "", "role": ""}}
-    if api == "completion":
+    if api == "completion" or api == "generate":
         accumulated_tokens = {"response": ""}
 
     span.add_event(Event.STREAM_START.value)
     try:
         async for chunk in response:
+            content = None
             if api == "chat":
+                content = chunk["message"]["content"]
                 accumulated_tokens["message"]["content"] += chunk["message"]["content"]
                 accumulated_tokens["message"]["role"] = chunk["message"]["role"]
             if api == "generate":
+                content = chunk["response"]
                 accumulated_tokens["response"] += chunk["response"]
 
-            span.add_event(
-                Event.STREAM_OUTPUT.value,
-                {
-                    SpanAttributes.LLM_CONTENT_COMPLETION_CHUNK: json.dumps(chunk),
-                },
-            )
+            set_event_completion_chunk(span, content)
         _set_response_attributes(span, chunk | accumulated_tokens)
     finally:
         # Finalize span after processing all chunks
